# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.0-beta.1

import enum

import winrt.system
from winrt import _winrt_windows_media_speechrecognition

__all__ = [
    "SpeechContinuousRecognitionMode",
    "SpeechRecognitionAudioProblem",
    "SpeechRecognitionConfidence",
    "SpeechRecognitionConstraintProbability",
    "SpeechRecognitionConstraintType",
    "SpeechRecognitionResultStatus",
    "SpeechRecognitionScenario",
    "SpeechRecognizerState",
    "SpeechContinuousRecognitionCompletedEventArgs",
    "SpeechContinuousRecognitionResultGeneratedEventArgs",
    "SpeechContinuousRecognitionSession",
    "SpeechRecognitionCompilationResult",
    "SpeechRecognitionGrammarFileConstraint",
    "SpeechRecognitionHypothesis",
    "SpeechRecognitionHypothesisGeneratedEventArgs",
    "SpeechRecognitionListConstraint",
    "SpeechRecognitionQualityDegradingEventArgs",
    "SpeechRecognitionResult",
    "SpeechRecognitionSemanticInterpretation",
    "SpeechRecognitionTopicConstraint",
    "SpeechRecognitionVoiceCommandDefinitionConstraint",
    "SpeechRecognizer",
    "SpeechRecognizerStateChangedEventArgs",
    "SpeechRecognizerTimeouts",
    "SpeechRecognizerUIOptions",
    "VoiceCommandManager",
    "VoiceCommandSet",
    "ISpeechRecognitionConstraint",
]

class SpeechContinuousRecognitionMode(enum.IntEnum):
    DEFAULT = 0
    PAUSE_ON_RECOGNITION = 1

class SpeechRecognitionAudioProblem(enum.IntEnum):
    NONE = 0
    TOO_NOISY = 1
    NO_SIGNAL = 2
    TOO_LOUD = 3
    TOO_QUIET = 4
    TOO_FAST = 5
    TOO_SLOW = 6

class SpeechRecognitionConfidence(enum.IntEnum):
    HIGH = 0
    MEDIUM = 1
    LOW = 2
    REJECTED = 3

class SpeechRecognitionConstraintProbability(enum.IntEnum):
    DEFAULT = 0
    MIN = 1
    MAX = 2

class SpeechRecognitionConstraintType(enum.IntEnum):
    TOPIC = 0
    LIST = 1
    GRAMMAR = 2
    VOICE_COMMAND_DEFINITION = 3

class SpeechRecognitionResultStatus(enum.IntEnum):
    SUCCESS = 0
    TOPIC_LANGUAGE_NOT_SUPPORTED = 1
    GRAMMAR_LANGUAGE_MISMATCH = 2
    GRAMMAR_COMPILATION_FAILURE = 3
    AUDIO_QUALITY_FAILURE = 4
    USER_CANCELED = 5
    UNKNOWN = 6
    TIMEOUT_EXCEEDED = 7
    PAUSE_LIMIT_EXCEEDED = 8
    NETWORK_FAILURE = 9
    MICROPHONE_UNAVAILABLE = 10

class SpeechRecognitionScenario(enum.IntEnum):
    WEB_SEARCH = 0
    DICTATION = 1
    FORM_FILLING = 2

class SpeechRecognizerState(enum.IntEnum):
    IDLE = 0
    CAPTURING = 1
    PROCESSING = 2
    SOUND_STARTED = 3
    SOUND_ENDED = 4
    SPEECH_DETECTED = 5
    PAUSED = 6

SpeechContinuousRecognitionCompletedEventArgs = _winrt_windows_media_speechrecognition.SpeechContinuousRecognitionCompletedEventArgs
SpeechContinuousRecognitionResultGeneratedEventArgs = _winrt_windows_media_speechrecognition.SpeechContinuousRecognitionResultGeneratedEventArgs
SpeechContinuousRecognitionSession = _winrt_windows_media_speechrecognition.SpeechContinuousRecognitionSession
SpeechRecognitionCompilationResult = _winrt_windows_media_speechrecognition.SpeechRecognitionCompilationResult
SpeechRecognitionGrammarFileConstraint = _winrt_windows_media_speechrecognition.SpeechRecognitionGrammarFileConstraint
SpeechRecognitionHypothesis = _winrt_windows_media_speechrecognition.SpeechRecognitionHypothesis
SpeechRecognitionHypothesisGeneratedEventArgs = _winrt_windows_media_speechrecognition.SpeechRecognitionHypothesisGeneratedEventArgs
SpeechRecognitionListConstraint = _winrt_windows_media_speechrecognition.SpeechRecognitionListConstraint
SpeechRecognitionQualityDegradingEventArgs = _winrt_windows_media_speechrecognition.SpeechRecognitionQualityDegradingEventArgs
SpeechRecognitionResult = _winrt_windows_media_speechrecognition.SpeechRecognitionResult
SpeechRecognitionSemanticInterpretation = _winrt_windows_media_speechrecognition.SpeechRecognitionSemanticInterpretation
SpeechRecognitionTopicConstraint = _winrt_windows_media_speechrecognition.SpeechRecognitionTopicConstraint
SpeechRecognitionVoiceCommandDefinitionConstraint = _winrt_windows_media_speechrecognition.SpeechRecognitionVoiceCommandDefinitionConstraint
SpeechRecognizer = _winrt_windows_media_speechrecognition.SpeechRecognizer
SpeechRecognizerStateChangedEventArgs = _winrt_windows_media_speechrecognition.SpeechRecognizerStateChangedEventArgs
SpeechRecognizerTimeouts = _winrt_windows_media_speechrecognition.SpeechRecognizerTimeouts
SpeechRecognizerUIOptions = _winrt_windows_media_speechrecognition.SpeechRecognizerUIOptions
VoiceCommandManager = _winrt_windows_media_speechrecognition.VoiceCommandManager
VoiceCommandSet = _winrt_windows_media_speechrecognition.VoiceCommandSet
ISpeechRecognitionConstraint = _winrt_windows_media_speechrecognition.ISpeechRecognitionConstraint
